-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2011 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Path = { }

function Path.new()
    local path = { }
    local value = 0
    local initial = 0
    local final = 0

    local timer = 0
    local period = 0

    local complete = true
    local completed = nil

    function path.schedule(self, newInitial, newFinal, newPeriod, completed)
        initial = newInitial
        final = newFinal
        period = newPeriod

        value = initial
        timer = 0

        complete = false
        completed = completed
    end

    function path.update(self, ms)
        if timer < period then
            -- Calculate new value based on the current and final values
            local increasing = (final > value)

            value = value + (final - value) / (period - timer) * min(period - timer, ms)

            if increasing then
                value = min(final, value)
            else
                value = max(final, value)
            end
        else
            value = final

            if not complete and isFunction(completed) then
                complete = true
                completed()
            end
        end

        timer = min(period, timer + ms)

        return value
    end

    function path.getValue(self)
        return value
    end

    function path.setValue(self, newValue)
        value = newValue

        -- Remove any scheduled path
        initial = value
        final = value
        period = 0
        timer = 0
        complete = true
        completed = nil

        return value
    end

    function path.setPeriod(self, newPeriod)
        period = newPeriod
    end

    return path
end

