-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2010 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("Utility/MiscSettings.lua")
require("UI/Input.lua")
require("UI/FormLayer.lua")
require("Settings/Controls.lua")

-- Common
Fbg2 = {
    version = "0.4",
    textWidth = 15,
    textHeight = 30,
    formX = -250,
    formY = 215,
    formWidth = 500,

    getAnimate = function() return MiscSettings.get("boolean", "animate", true) end,
}

-- Modes
Fbg2.modeNames = {
    "Classic",
    "Cleanup",
}

Fbg2.modes = { }

local i = 1

while i <= #Fbg2.modeNames do
    Fbg2.modes[Fbg2.modeNames[i]] = i
    i = i + 1
end

-- Window title
Video.setTitle("Falling Block Game 2")

Form.setDefaultTextSize(Fbg2.textWidth, Fbg2.textHeight)

-- Controls
Fbg2.logicalEvents = {
    up = { necessary = true },
    down = { necessary = true },
    left = { necessary = true },
    right = { necessary = true },
    rotateLeft = { },
    rotateRight = { },
    activate = { necessary = true },
    delete = { },
    cancel = { },
    openConsole = { },
}

Fbg2.input = Input.new(Fbg2.logicalEvents, controlsData)
FormLayer.setDefaultInput(Fbg2.input)

-- Score/level/cleared counters
Fbg2.digitSize = 40

-- Block images (shared between Piece and Board)
Fbg2.blockSize = 22
Fbg2.blockImages = {
    nil,
    "Images/LeftSnake.png",
    "Images/RightSnake.png",
    "Images/LeftGun.png",
    "Images/RightGun.png",
    "Images/Square.png",
    "Images/Line.png",
    "Images/Tee.png",
}

