-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2010 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("Fbg2/Common.lua")

Counter = { }

function Counter.new(digitCount, x, y, animated)
    local counter = Entity.new(x, y, 0.5, Fbg2.digitSize, Fbg2.digitSize)
    local digits = { }

    counter.digitCount = digitCount
    counter.digits = digits

    -- Used for animation
    counter.value = 0
    counter.base = 0
    counter.target = 0
    counter.timer = 0
    counter.timerStart = 0

    local function setDigit(power, digitValue)
        local digit = digits[power]

        digit.u1 = (digitValue % 4) / 4
        digit.v1 = floor(digitValue / 4) / 4

        digit.u2 = ((digitValue % 4) + 1) / 4
        digit.v2 = (floor(digitValue / 4) + 1) / 4
    end

    function counter.showValue(self)
        local power = 0

        while power < self.digitCount do
            local digitValue = (floor(self.value / pow(10, power))) % 10

            setDigit(power, digitValue)
            power = power + 1
        end
    end

    function counter.setValue(self, value, period)
        self.target = value

        -- Only animate when increasing (e.g. reset does not animate)
        if animated and value > self.value and period > 0 then
            self.timerStart = period
            self.timer = period
            self.base = self.value
        else
            self.value = value
            self:showValue()
        end
    end

    if animated then
        function counter.update(self, ms)
            local lastValue = self.value

            self.timer = max(0, self.timer - ms)

            if self.value < self.target then
                self.value = self.base + (self.target - self.base) * (self.timerStart - self.timer) / self.timerStart
            end

            if self.value ~= lastValue then
                self:showValue()
            end
        end
    end

    -- Add each digit
    local power = 0

    while power < digitCount do
        local digit = Element.ImageRegion.new("Images/Digits.png", 0, 0, 1, 1, (digitCount - power) - 0.5, -0.5)

        digits[power] = digit
        setDigit(power, 0)
        counter.elements:add(digit)

        power = power + 1
    end

    return counter
end

