-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2011 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("Fbg2/Common.lua")
require("UI/Layers.lua")
require("Fbg2/Board.lua")
require("Fbg2/Piece.lua")
require("Fbg2/Counter.lua")
require("UI/UI.lua")

GameLayer = {
    clearedToScorePeriod = {
        [0] = 0,
        [1] = 100,
        [2] = 250,
        [3] = 500,
        [4] = 750,
    }
}

function GameLayer.new(ended)
    -- TODO: Make it so that you can set a frame period but still get instantaneous updates on input!
    -- TODO: Option for higher framerate?
    local gameLayer = Layer.new(33)

    gameLayer.propagateAudio = false

    local boardX = -270
    local boardY = -220

    Fbg2.input:setupEventHandlers(gameLayer)
    
    function gameLayer.inputReceived(self, event, pressed)
        return self.board:inputReceived(event, pressed)
    end
    
    function gameLayer.errorOccurred(self, message)
        print(message)
        console:show()
    end

    function gameLayer.start(self, mode, level, height)
        self.board:reset(mode, level, height)
        Layers.push(self)
        self:playMusic("Music/FallingBlockGameSndTrk.ogg")
    end

    -- Background
    gameLayer:addChild(Entity.new(0, 0, -1, 640, 480, 0, Color.new(1, 1, 1), ElementList.new(Element.Image.new("Images/Background.png"))))

    -- Cover the top of pieces that extend beyond the board
    gameLayer:addChild(Entity.new(0, 230, 0.5, 640, 20, 0, Color.new(1, 1, 1), ElementList.new(Element.ImageRegion.new("Images/Background.png", 0, 0, 1, 0.041666667))))
    
    local scoreLabel = gameLayer:addChild(Counter.new(7, 16, -20, true))
    local levelLabel = gameLayer:addChild(Counter.new(2, 4, 50))
    local clearedLabel = gameLayer:addChild(Counter.new(3, 186, 50))

    -- Add the main board
    gameLayer.board = gameLayer:addChild(Board.new(Fbg2.blockSize,
        function(score, cleared, level, lines)
            scoreLabel:setValue(score, GameLayer.clearedToScorePeriod[lines])
            clearedLabel:setValue(cleared)
            levelLabel:setValue(level)
        end,
        
        function(valid, mode, height, score, cleared, level)
            gameLayer:clearAudio()
            Layers.pop()
            ended(valid, mode, height, score, cleared, level)
        end))

    -- Position board and next piece
    gameLayer.board.x = boardX
    gameLayer.board.y = boardY
    
    local nextPiece = gameLayer:addChild(gameLayer.board:getNextPiece(154, -165))

    return gameLayer
end

