-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2010 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("UI/UI.lua")
require("Fbg2/Common.lua")
require("Menus/HighScore.lua")

HighScoreScreen = { }

function HighScoreScreen.new(page)
    local highScoreForm = Form.newGrid(1, -300, Fbg2.formY, 600)

    -- Activate/cancel exit
    local title = Title.new("High Scores")

    title.getActive = nil

    function title.inputReceived(self, event, pressed)
        if pressed then
            if event == "activate" then
                Layers.pop()
            end
        end
    end

    -- Create form
    highScoreForm:add(title)
    highScoreForm:add(Separator.new())

    -- Add all entries
    local list = highScoresLists[page]
    local i = 1

    highScoreForm:add(Label.new(HighScore.getPageName(page)))
    highScoreForm.nameLabels = { }
    highScoreForm.scoreLabels = { }

    list:forEach(function(highScore)
        local nameLabel = Label.new("")
        local scoreLabel = Label.new("", "right")

        highScoreForm:add(Form.newNestedGrid(2, nameLabel, scoreLabel))
        highScoreForm.nameLabels[i] = nameLabel
        highScoreForm.scoreLabels[i] = scoreLabel
        i = i + 1
    end)

    function highScoreForm.refresh(self)
        -- Add all scores
        local list = highScoresLists[page]
        local i = 1

        list:forEach(function(highScore)
            highScoreForm.nameLabels[i]:setText(highScore.name .. " (Level " .. highScore.level .. ")")
            -- TODO: String parameters should accept numbers (but note that this converts the type of the object from the C API!)
            highScoreForm.scoreLabels[i]:setText("" .. highScore.score)
            i = i + 1
        end)
    end

    local highScoreScreen = FormLayer.new(highScoreForm)

    function highScoreScreen.formShown(self)
        highScoreForm:refresh()
    end

    return highScoreScreen
end

HighScoreMenu = { }

function HighScoreMenu.new()
    local screens = { }
    local i = 1

    while i <= HighScore.getPageCount() do
        screens[#screens + 1] = HighScoreScreen.new(i)
        i = i + 1
    end
    
    return {
        show = function(self, page)
            if isNumber(page) and page >= 1 and page <= HighScore.getPageCount() then
                -- Show only the relevant page
                screens[page]:show()
            else
                -- Push all screens
                local s = #screens

                while s >= 1 do
                    screens[s]:show()
                    s = s - 1
                end
            end
        end,
    }
end

